/*
 * Copyright (c) 2006 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: 
 */
package edu.indiana.extreme.xbaya.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.border.Border;

import edu.indiana.extreme.xbaya.util.SwingUtil;

/**
 * @author Satoshi Shirasuna
 */
public class ScrollPanel implements XBayaComponent {

    private JPanel panel;

    private JComponent component;

    /**
     * Creates a ScrollPanel.
     * 
     * @param component
     * @param title
     */
    public ScrollPanel(XBayaComponent component, String title) {
        this(component.getSwingComponent(), title);
    }

    /**
     * Creates a ScrollPanel.
     * 
     * @param component
     * @param title
     */
    public ScrollPanel(JComponent component, String title) {
        this(component, title, true);
    }

    /**
     * Creates a ScrollPanel.
     * 
     * @param component
     * @param title
     * @param scroll
     */
    public ScrollPanel(XBayaComponent component, String title, boolean scroll) {
        this(component.getSwingComponent(), title, scroll);
    }

    /**
     * Creates a ScrollPanel.
     * 
     * @param component
     * @param title
     * @param scroll
     */
    public ScrollPanel(JComponent component, String title, boolean scroll) {
        this.component = component;
        init(component, title, scroll);
    }

    /**
     * @see edu.indiana.extreme.xbaya.gui.XBayaComponent#getSwingComponent()
     */
    public JPanel getSwingComponent() {
        return getPanel();
    }

    /**
     * @return The panel.
     */
    public JPanel getPanel() {
        return this.panel;
    }

    /**
     * @param preferredSize
     */
    public void setPrefferedSize(Dimension preferredSize) {
        this.component.setPreferredSize(preferredSize);
    }

    private void init(JComponent comp, String title, boolean scroll) {
        this.panel = new JPanel();
        this.panel.setLayout(new BorderLayout());

        JLabel titleLabel = new JLabel(title);
        Border border = BorderFactory.createEtchedBorder();
        titleLabel.setBorder(border);
        this.panel.add(titleLabel, BorderLayout.NORTH);

        if (scroll) {
            JScrollPane scrollPane = new JScrollPane(comp);
            scrollPane.setMinimumSize(SwingUtil.MINIMUM_SIZE);
            this.panel.add(scrollPane, BorderLayout.CENTER);
        } else {
            comp.setMinimumSize(SwingUtil.MINIMUM_SIZE);
            this.panel.add(comp, BorderLayout.CENTER);
        }
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
